---
name: User story
about: A user-oriented story describing a piece of work to do
title: ""
labels: ""
assignees: ""
---

## Description

As a <user type>, I want to <do something>, so that I can <accomplish something>

## Discussion

Provide detailed discussion here

## Acceptance Criteria

<!-- Remove any that don't apply -->

- [ ] Unit tests cover new/changed code
- [ ] Examples build against new/changed code
- [ ] READMEs are updated
- [ ] Type of [semantic version](https://semver.org/) change is identified
